@@ -4,6 +4,7 @@ from typing import List, Union
 
 from .._base import NoExtraBaseModel
 from .constructionset import ConstructionSetAbridged, ConstructionSet
+from .global_constructionset import GlobalConstructionSet
 from .construction import OpaqueConstructionAbridged, WindowConstructionAbridged, \
     ShadeConstruction, AirBoundaryConstructionAbridged, OpaqueConstruction, \
     WindowConstruction, AirBoundaryConstruction, WindowConstructionShadeAbridged, \
@@ -19,6 +20,7 @@ from .load import PeopleAbridged, LightingAbridged, ElectricEquipmentAbridged, \
 from .daylight import DaylightingControl
 from .ventcool import VentilationControlAbridged, VentilationOpening, \
     VentilationSimulationControl, AFNCrack
+from .internalmass import InternalMassAbridged
 from .schedule import ScheduleTypeLimit, ScheduleRulesetAbridged, \
     ScheduleFixedIntervalAbridged, ScheduleRuleset, ScheduleFixedInterval
 from .hvac.idealair import IdealAirSystemAbridged
@@ -203,12 +205,28 @@ class RoomEnergyPropertiesAbridged(NoExtraBaseModel):
         'of windows. If None, the windows will never open.'
     )
 
+    internal_masses: List[InternalMassAbridged] = Field(
+        default=None,
+        description='An optional list of of InternalMass objects for thermal mass '
+        'exposed to Room air. Note that internal masses assigned this way cannot "see" '
+        'solar radiation that may potentially hit them and, as such, caution should be '
+        'taken when using this component with internal mass objects that are not '
+        'always in shade. Masses are factored into the the thermal calculations '
+        'of the Room by undergoing heat transfer with the indoor air.'
+    )
+
 
 class ModelEnergyProperties(NoExtraBaseModel):
 
     type: constr(regex='^ModelEnergyProperties$') = \
         'ModelEnergyProperties'
 
+    global_construction_set: GlobalConstructionSet = Field(
+        default=GlobalConstructionSet(),
+        description='Global Energy construction set.',
+        readOnly=True
+    )
+
     construction_sets: List[Union[ConstructionSetAbridged, ConstructionSet]] = Field(
         default=None,
         description='List of all unique ConstructionSets in the Model.'
@@ -265,4 +283,4 @@ class ModelEnergyProperties(NoExtraBaseModel):
         default=None,
         description='An optional parameter to define the global parameters for '
         'a ventilation cooling.'
-    )
\ No newline at end of file
+    )
